@@ -15,6 +15,20 @@
 
 class CloudConfig(object):
     def __init__(self, name, region, config):
-        self.name = name
+        self.name = name or 'openstack'
         self.region = region
         self.config = config
+
+    def __getattr__(self, key):
+        """Return arbitrary attributes."""
+
+        if key.startswith('os_'):
+            key = key[3:]
+
+        if key in [attr.replace('-', '_') for attr in self.config]:
+            return self.config[key]
+        else:
+            return None
+
+    def __iter__(self):
+        return self.config.__iter__()
