@@ -88,11 +88,17 @@ class OpenStackConfig(object):
 
         self._cache_max_age = 300
         self._cache_path = CACHE_PATH
+        self._cache_class = 'dogpile.cache.memory'
+        self._cache_arguments = {}
         if 'cache' in self.cloud_config:
             self._cache_max_age = self.cloud_config['cache'].get(
                 'max_age', self._cache_max_age)
             self._cache_path = os.path.expanduser(
                 self.cloud_config['cache'].get('path', self._cache_path))
+            self._cache_class = self.cloud_config['cache'].get(
+                'class', self._cache_class)
+            self._cache_arguments = self.cloud_config['cache'].get(
+                'arguments', self._cache_arguments)
 
     def _load_config_file(self):
         for path in self._config_files:
@@ -112,6 +118,12 @@ class OpenStackConfig(object):
     def get_cache_path(self):
         return self._cache_path
 
+    def get_cache_class(self):
+        return self._cache_class
+
+    def get_cache_arguments(self):
+        return self._cache_arguments
+
     def _get_regions(self, cloud):
         try:
             return self.cloud_config['clouds'][cloud]['region_name']
@@ -197,7 +209,7 @@ class OpenStackConfig(object):
 
         os_args = dict()
         new_args = dict()
-        for (key, val) in args.iteritems():
+        for (key, val) in iter(args.items()):
             key = key.replace('-', '_')
             if key.startswith('os'):
                 os_args[key[3:]] = val
@@ -285,7 +297,7 @@ class OpenStackConfig(object):
             config['auth'] = dict()
 
         # Can't just do update, because None values take over
-        for (key, val) in args.iteritems():
+        for (key, val) in iter(args.items()):
             if val is not None:
                 config[key] = val
 
@@ -294,6 +306,10 @@ class OpenStackConfig(object):
                 if type(config[key]) is not bool:
                     config[key] = get_boolean(config[key])
 
+        if 'auth_plugin' in config:
+            if config['auth_plugin'] in ('', 'None', None):
+                validate = False
+
         if validate and ksc_auth:
             config = self._validate_auth(config)
 
